%===========================================================
%====== EXAMPLE 1: input file for the CONVERGENCE example
%===========================================================
% uniform FSD, no bonds

params = struct('N'   ,30000,   ...  % number of floes (-)
                'arat',2.0,     ...  % model domain's aspect ratio Lx/Ly (-)
                'A',0.3,        ...  % ice concentration (-)
                'rho',910.0,    ...  % ice density (kg/m3)
                'h',1.5,        ...  % ice thickness (m)
                'Vwrite',0);         % write the 'Velocities' section?
rdist = struct('type','unif','rmin',50,'rmax',150);
Vdist = struct('type','norm','Vrndmeanx',0.0,'Vrndstdx',1e-10, ...
                             'Vrndmeany',0.0,'Vrndstdy',1e-10); 
parbnd = struct('ibnd'   ,0,    ...  % whether bond-related info should be written to the header
                                ...  %  (0=no bond info; 1=only space for bonds left, but no. of bonds = 0; 
                                ...  %   2=bonds created between all grains separated by less than dmax) 
                'nextra',5,     ...  % No. of "extra bond per atom"
                'dmax',5.0,     ...  % 
                'nbondtypes',2, ...  % No. of bond types
                'bondtyperatio',...
                     [0.8 0.2], ...  % proportions of various types of bonds
                'bondstoremove',...
                     0.0        ...  % proportion of bonds to be removed from the total
                );
[L,r,Rx,Ry,Vx,Vy] = LIGGGHTSinit(params,rdist,Vdist,parbnd,'conv_N3e4_A03.init');

%===========================================================
%====== EXAMPLE 2: input file for the WIND example
%===========================================================
% power law FSD, no bonds

params = struct('N'   ,30000,   ...  % number of floes (-)
                'arat',1.0,     ...  % model domain's aspect ratio Lx/Ly (-)
                'A',0.6,        ...  % ice concentration (-)
                'rho',910.0,    ...  % ice density (kg/m3)
                'h',1.5,        ...  % ice thickness (m)
                'Vwrite',0);         % write the 'Velocities' section?
rdist = struct('type','powerlaw','rmean',4,'alpha',1.8);
Vdist = struct('type','norm','Vrndmeanx',0.0,'Vrndstdx',1e-10, ...
                             'Vrndmeany',0.0,'Vrndstdy',1e-10); 
parbnd = struct('ibnd'   ,0,    ...  % whether bond-related info should be written to the header
                                ...  %  (0=no bond info; 1=only space for bonds left, but no. of bonds = 0; 
                                ...  %   2=bonds created between all grains separated by less than dmax) 
                'nextra',5,     ...  % No. of "extra bond per atom"
                'dmax',5.0,     ...  % 
                'nbondtypes',2, ...  % No. of bond types
                'bondtyperatio',...
                     [0.8 0.2], ...  % proportions of various types of bonds
                'bondstoremove',...
                     0.0        ...  % proportion of bonds to be removed from the total
                );
[L,r,Rx,Ry,Vx,Vy] = LIGGGHTSinit(params,rdist,Vdist,parbnd,'wind_N3e4_A06.init');

%===========================================================
%====== EXAMPLE 3: input file for the TENSILEBREAK example
%===========================================================
% based on the output of the CONVERGENCE run
% (you have to run that case first and to adjust the paths below if you want to run this example)

const = readdump('W:\users\oceagah\liggghts_seaice\convergence\res\conv03.const');
res = readdump('W:\users\oceagah\liggghts_seaice\convergence\res\conv03.10800000');
atomdata = assembleresults(const,res);
params.rho = 910; params.h = 1.5; params.Vwrite = 0;
parbnd = struct('ibnd'   ,2,    ...  % whether bond-related info should be written to the header
                                ...  %  (0=no bond info; 1=only space for bonds left, but no. of bonds = 0; 
                                ...  %   2=bonds created between all grains separated by less than dmax) 
                'nextra',7,     ...  % No. of "extra bond per atom"
                'dmax',5.0,     ...  % 
                'nbondtypes',1, ...  % No. of bond types
                'bondtyperatio',...
                     [1.0 0.0], ...  % proportions of various types of bonds
                'bondstoremove',...
                     0.0        ...  % proportion of bonds to be removed from the total
                );
% we cut out only a subset of grains from a densely-packed region:
ind = find(atomdata.x>-1.45e4 & atomdata.x<-0.2e4);
atomdata.r = atomdata.r(ind);
atomdata.x = atomdata.x(ind);
atomdata.x = atomdata.x - mean(atomdata.x);
atomdata.y = atomdata.y(ind);
atomdata.id = (1:length(ind))';
atomdata.L(1) = 2*max(abs(atomdata.x));
atomdata.L = 1.01*atomdata.L;
[L,r,Rx,Ry,Vx,Vy] = LIGGGHTSinit_fromdump(atomdata,params,parbnd,'tensilebreak_A3_ibnd2.init');
plotfloepositions(atomdata.x,atomdata.y,atomdata.r,atomdata.r,atomdata.L,[50 150]);
b2r = 0.1:0.1:0.5;
for n = 1:length(b2r)
    parbnd.bondstoremove = b2r(n);
    [L,r,Rx,Ry,Vx,Vy] = LIGGGHTSinit_fromdump(atomdata,params,parbnd,['tensilebreak_A3_ibnd2_b2r' num2str(b2r(n),'%3.1f') '.init']);
end
